import './App.css'
import { Routes, Route, Link } from 'react-router-dom'
import Home from './features/Home/Home'
import Catalog from './features/Catalog/Catalog'
import NotFound from './features/NotFound/NotFound'
import { Container, Paper, Theme } from '@mui/material'
import { ThemeProvider } from '@emotion/react'
import { useSelector } from 'react-redux'
import { RootState } from './features/redux/store'
import Login from './features/Auth/Login'
import CatalogItemDetail from './features/Catalog/CatalogItemDetail'
import Navigation from './features/Navigation/Navigation'

const App = () => {
    const theme: Theme = useSelector((state: RootState) => state.theme.theme)

    return (
        <ThemeProvider theme={theme}>
            <Navigation>
                    <Container>
                        <Routes>
                            <Route path="/" element={<Home />} />
                            <Route path="/catalog" element={<Catalog />} />
                            <Route
                                path="/catalog/:itemId"
                                element={<CatalogItemDetail />}
                            />
                            <Route path="/login" element={<Login />} />
                            <Route path="*" element={<NotFound />} />
                        </Routes>
                    </Container>
            </Navigation>
        </ThemeProvider>
    )
}

export default App
